@@ -1,4 +1,4 @@
-#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,6 +15,8 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+from __future__ import print_function
+
 def lamdaContainer(x):
     f = lambda c : c
     g = lambda c : c if x else c*c
@@ -23,30 +25,39 @@ def lamdaContainer(x):
     y = f(x)
 
     if 'a' <= x <= y <= 'z':
-        print "Four"
+        print("Four")
 
     if 'a' <= x <= 'z':
-        print "Yes"
+        print("Yes")
 
     if 'a' <= x > 'z':
-        print "Yes1"
+        print("Yes1")
 
     if 'a' <= ('1' if x else '2') > 'z':
-        print "Yes2"
+        print("Yes2")
 
     if 'a' <= ('1' if x else '2') > 'z' > i:
-        print "Yes3"
+        print("Yes3")
 
     z = lambda huhu = y : huhu
 
-    print "Lambda defaulted gives", z()
+    print("Lambda defaulted gives", z())
 
-lamdaContainer( "b" )
+lamdaContainer('b')
 
-def lambaGenerator():
+def lambdaGenerator():
     x = lambda : (yield 3)
 
     gen = x()
-    print "Lambda generator gives", gen.next()
+    print("Lambda generator gives", next(gen))
 
-lambaGenerator()
+lambdaGenerator()
+
+def lambdaDirectCall():
+    args = range(7)
+
+    x = (lambda *args:args)(*args)
+
+    print("Lambda direct call gave", x)
+
+lambdaDirectCall()
